@@ -513,7 +513,7 @@ void MainProgramScore(InputScore *inputScore, int nProc, int rank)
                 jEnd = jStart + linkSNPNum[i];
                 /* 各haplotypeブロック内でループ */
                 for (j = jStart; j < jEnd; j++){
-                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t \n", 
+                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t \n", 
                         blockArea[i],
                         blockArea[i+1],
                         linkSNPNum[i],
@@ -530,7 +530,7 @@ void MainProgramScore(InputScore *inputScore, int nProc, int rank)
                 jEnd = jStart + linkSNPNum[i];
                 /* 各haplotypeブロック内でループ */
                 for (j = jStart; j < jEnd; j++){
-                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t \n", 
+                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t \n", 
                         snpData1[ linkSNPStart[i] ].pos,
                         snpData1[ linkSNPStart[i] + linkSNPNum[i] - 1 ].pos,
                         linkSNPNum[i],
