@@ -280,7 +280,7 @@ void MainProgramMulti(InputTypeI *inputTypeI)
     if (inputTypeI->areaFileType == 0){
         for (i = 0; i < blockNum; i++){
             if (Sobs[i] != 0){
-                fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t", 
+                fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t", 
                     blockArea[i],
                     blockArea[i+1],
                     linkSNPNum[i],
@@ -289,7 +289,7 @@ void MainProgramMulti(InputTypeI *inputTypeI)
                     Sobs[i]);
                 /* type I erroro */
                 for (index = 0; index < repeat; index++){
-                    fprintf(fpOut, "%.10lf\t", typeIError[i*repeat+index]);
+                    fprintf(fpOut, "%.3e\t", typeIError[i*repeat+index]);
                 }
                 fprintf(fpOut, "\n");
             }
@@ -304,7 +304,7 @@ void MainProgramMulti(InputTypeI *inputTypeI)
     else {
         for (i = 0; i < blockNum; i++){
             if (Sobs[i] != 0){
-                fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t", 
+                fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t", 
                     snpData1[ linkSNPStart[i] ].pos,
                     snpData1[ linkSNPStart[i] + linkSNPNum[i] - 1 ].pos,
                     linkSNPNum[i],
@@ -313,7 +313,7 @@ void MainProgramMulti(InputTypeI *inputTypeI)
                     Sobs[i]);
                 /* type I erroro */
                 for (index = 0; index < repeat; index++){
-                    fprintf(fpOut, "%.10lf\t", typeIError[i*repeat+index]);
+                    fprintf(fpOut, "%.3e\t", typeIError[i*repeat+index]);
                 }
                 fprintf(fpOut, "\n");
             }
