@@ -580,7 +580,7 @@ void MainProgramMulti(InputTypeI *inputTypeI, int nProc, int rank)
         if (inputTypeI->areaFileType == 0){
             for (i = 0; i < blockNum; i++){
                 if (SobsAll[i] != 0){
-                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t", 
+                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t", 
                             blockArea[i],
                             blockArea[i+1],
                             linkSNPNum[i],
@@ -589,7 +589,7 @@ void MainProgramMulti(InputTypeI *inputTypeI, int nProc, int rank)
                             SobsAll[i]);
                     /* type I errorを出力 */
                     for (index = 0; index < repeat; index++){
-                        fprintf(fpOut, "%.10lf\t", typeIErrorAll[i*repeat+index]);
+                        fprintf(fpOut, "%.3e\t", typeIErrorAll[i*repeat+index]);
                     }
                     fprintf(fpOut, "\n");
                 }
@@ -604,7 +604,7 @@ void MainProgramMulti(InputTypeI *inputTypeI, int nProc, int rank)
         else {
             for (i = 0; i < blockNum; i++){
                 if (SobsAll[i] != 0){
-                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.10lf\t", 
+                    fprintf(fpOut, "%ld-%ld\t%ld\t%s\t%ld\t%.3e\t", 
                             snpData1[ linkSNPStart[i] ].pos,
                             snpData1[ linkSNPStart[i] + linkSNPNum[i] - 1 ].pos,
                             linkSNPNum[i],
@@ -613,7 +613,7 @@ void MainProgramMulti(InputTypeI *inputTypeI, int nProc, int rank)
                             SobsAll[i]);
                     /* type I errorを出力 */
                     for (index = 0; index < repeat; index++){
-                        fprintf(fpOut, "%.10lf\t", typeIErrorAll[i*repeat+index]);
+                        fprintf(fpOut, "%.3e\t", typeIErrorAll[i*repeat+index]);
                     }
                     fprintf(fpOut, "\n");
                 }
